@@ -19,7 +19,7 @@ class AwsOkta:
         try:
             profile = get_profile(self.resource)
         except KeyError:
-            raise CliError(f"Could not find resource {self.resource}")
+            raise CliError(f"Invalid resource: {self.resource}")
         options = [
             arg
             for (key, value) in kwargs.items()
