@@ -13,7 +13,7 @@ class ConfigSchema(TypedDict, total=False):
     org: str
 
 
-class Config(MutableMapping[ConfigKey, Any]):
+class Config(MutableMapping):
     __slots__ = ["path", "config"]
 
     path: Final[Path]
