@@ -25,11 +25,11 @@ PARAMS: Dict[str, OrgParams] = {
                 "Catfood", "arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic"
             ),
             "prod-private": Profile(
-                "Prod (Intuit)",
+                "Prod: Intuit",
                 "arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
             ),
             "staging-private": Profile(
-                "Staging (Intuit)",
+                "Staging: Intuit",
                 "arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
             ),
         }
